|project|
=========

A CLI for `Vuforia Web Services`_.

.. _Vuforia Web Services: https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API

.. include:: install.rst

.. include:: usage-example.rst

Reference
---------

.. toctree::
   :maxdepth: 3

   install
   usage-example
   commands
   contributing
   release-process
   changelog
